@@ -67,6 +67,7 @@ new CloudFrontToS3(this, "test-cloudfront-s3", new CloudFrontToS3Props.Builder()
 |bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3.BucketProps.html)|Optional user provided props to override the default props for the S3 Bucket.|
 |cloudFrontDistributionProps?|[`cloudfront.DistributionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.DistributionProps.html)|Optional user provided props to override the default props for CloudFront Distribution|
 |insertHttpSecurityHeaders?|`boolean`|Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from CloudFront|
+| responseHeadersPolicyProps?   | [`cloudfront.ResponseHeadersPolicyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.ResponseHeadersPolicyProps.html) | Optional user provided configuration that cloudfront applies to all http responses.|
 |originPath?|`string`|Optional user provided props to provide an[originPath](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront_origins.S3OriginProps.html#originpath) that CloudFront appends to the origin domain name when CloudFront requests content from the origin. The string should start with a `/`, for example: `/production`. Default value is `'/'`|
 |loggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3.BucketProps.html)|Optional user provided props to override the default props for the S3 Logging Bucket.|
 |cloudFrontLoggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3.BucketProps.html)|Optional user provided props to override the default props for the CloudFront Logging Bucket.|
@@ -149,6 +150,7 @@ class CloudFrontToS3(
         logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         origin_path: typing.Optional[builtins.str] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -157,10 +159,11 @@ class CloudFrontToS3(
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
         :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
-        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
+        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
         :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
         :param origin_path: Optional user provided props to provide an originPath that CloudFront appends to the origin domain name when CloudFront requests content from the origin. The string should start with a ``/``, for example ``/production``.
+        :param response_headers_policy_props: Optional user provided configuration that cloudfront applies to all http responses. Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or ResponseHeadersCorsBehavior to the cloudfront distribution. Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true`` and ResponseSecurityHeadersBehavior is passed. Default: - undefined
 
         :access: public
         :since: 0.8.0
@@ -179,6 +182,7 @@ class CloudFrontToS3(
                 logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
                 log_s3_access_logs: typing.Optional[builtins.bool] = None,
                 origin_path: typing.Optional[builtins.str] = None,
+                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -193,6 +197,7 @@ class CloudFrontToS3(
             logging_bucket_props=logging_bucket_props,
             log_s3_access_logs=log_s3_access_logs,
             origin_path=origin_path,
+            response_headers_policy_props=response_headers_policy_props,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -240,6 +245,7 @@ class CloudFrontToS3(
         "logging_bucket_props": "loggingBucketProps",
         "log_s3_access_logs": "logS3AccessLogs",
         "origin_path": "originPath",
+        "response_headers_policy_props": "responseHeadersPolicyProps",
     },
 )
 class CloudFrontToS3Props:
@@ -254,16 +260,18 @@ class CloudFrontToS3Props:
         logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         origin_path: typing.Optional[builtins.str] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
         :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
-        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
+        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
         :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
         :param origin_path: Optional user provided props to provide an originPath that CloudFront appends to the origin domain name when CloudFront requests content from the origin. The string should start with a ``/``, for example ``/production``.
+        :param response_headers_policy_props: Optional user provided configuration that cloudfront applies to all http responses. Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or ResponseHeadersCorsBehavior to the cloudfront distribution. Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true`` and ResponseSecurityHeadersBehavior is passed. Default: - undefined
 
         :summary: The properties for the CloudFrontToS3 Construct
         '''
@@ -273,6 +281,8 @@ class CloudFrontToS3Props:
             cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(logging_bucket_props, dict):
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+        if isinstance(response_headers_policy_props, dict):
+            response_headers_policy_props = aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps(**response_headers_policy_props)
         if __debug__:
             def stub(
                 *,
@@ -284,6 +294,7 @@ class CloudFrontToS3Props:
                 logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
                 log_s3_access_logs: typing.Optional[builtins.bool] = None,
                 origin_path: typing.Optional[builtins.str] = None,
+                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -295,6 +306,7 @@ class CloudFrontToS3Props:
             check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
             check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
             check_type(argname="argument origin_path", value=origin_path, expected_type=type_hints["origin_path"])
+            check_type(argname="argument response_headers_policy_props", value=response_headers_policy_props, expected_type=type_hints["response_headers_policy_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
@@ -312,6 +324,8 @@ class CloudFrontToS3Props:
             self._values["log_s3_access_logs"] = log_s3_access_logs
         if origin_path is not None:
             self._values["origin_path"] = origin_path
+        if response_headers_policy_props is not None:
+            self._values["response_headers_policy_props"] = response_headers_policy_props
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -355,6 +369,9 @@ class CloudFrontToS3Props:
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
         '''Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
 
+        Turning this on will inject default headers and is mutually exclusive with passing custom security headers
+        via the responseHeadersPolicyProps parameter.
+
         :default: - true
         '''
         result = self._values.get("insert_http_security_headers")
@@ -391,6 +408,24 @@ class CloudFrontToS3Props:
         result = self._values.get("origin_path")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def response_headers_policy_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps]:
+        '''Optional user provided configuration that cloudfront applies to all http responses.
+
+        Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
+        ResponseHeadersCorsBehavior to the cloudfront distribution.
+
+        Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers
+        via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true``
+        and ResponseSecurityHeadersBehavior is passed.
+
+        :default: - undefined
+        '''
+        result = self._values.get("response_headers_policy_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
